@@ -1,6 +1,6 @@
 """
 ****************************************************************************************************
-:copyright (c) 2020-2021, Alliance for Sustainable Energy, LLC.
+:copyright (c) 2020-2023, Alliance for Sustainable Energy, LLC.
 All rights reserved.
 ****************************************************************************************************
 """
@@ -312,6 +312,113 @@ class TestModel(TestCase, DiffAssertions):
                                 ['parameter String myParam="supercalifragilisticexpialidocious" "a comment"'])
         self.assertNoDeletions(source_file, self.result)
 
+    def test_model_reclaration_string_replacement(self):
+        """Should update redeclaration of a component"""
+        # Setup
+        source_file = os.path.join(self.data_dir, 'Office.mo')
+        model = Model(source_file)
+
+        # Act
+
+        model.overwrite_component_redeclaration(
+            'Buildings.ThermalZones.ReducedOrder.RC.TwoElements',
+            'thermalZoneTwoElements',
+            'Medium = Buildings.Media.Air',)
+        self.result = model.execute()
+
+        # Assert
+        self.assertHasAdditions(source_file, self.result, ['redeclare package Medium = Buildings.Media.Air'])
+        self.assertHasDeletions(source_file, self.result, ['Modelica.Media.Air.DryAirNasa'])
+
+    def test_model_reclaration_string_no_assign_replacement(self):
+        """Update a redeclare statement with a string. This is used when the
+        redeclare clause doesn't have a assignment
+        """
+        source_file = os.path.join(self.data_dir, 'Office.mo')
+        model = Model(source_file)
+
+        # Act
+        model.overwrite_component_redeclaration(
+            'IDEAS.Buildings.Components.Window',
+            'MMM_Fixed_3000_x_2000mm_3__WinRoom0BoQ',
+            'IDEAS.Buildings.Components.Shading.Screen shaType',
+            existing_redeclaration='IDEAS.Buildings.Components.Shading.None shaType',
+        )
+        model.overwrite_component_redeclaration(
+            'IDEAS.Buildings.Components.Window',
+            'MMM_Fixed_3000_x_2000mm_3__WinRoom0BoQ',
+            'Something.Else Fun',
+            existing_redeclaration='IDEAS.Buildings.Data.Frames.AluminiumInsulated fraType',
+        )
+        self.result = model.execute()
+
+        # Debug
+        # model.save_as(os.path.join(self.data_dir, 'Office2.mo'))
+
+        # Assert
+        self.assertHasAdditions(source_file, self.result,
+                                ['IDEAS.Buildings.Components.Shading.Screen shaType',
+                                 'redeclare Something.Else Fun'])
+        self.assertHasDeletions(source_file, self.result,
+                                ['IDEAS.Buildings.Components.Shading.None shaType',
+                                 'redeclare IDEAS.Buildings.Data.Frames.AluminiumInsulated fraType'])
+
+    def test_model_remove_component_argument(self):
+        """Should remove an argument in an existing component."""
+        # Setup
+        source_file = os.path.join(self.data_dir, 'DCMotor.mo')
+        model = Model(source_file)
+
+        # Act
+        model.remove_component_argument('ElectroMechanicalElement', 'EM', 'J')
+        self.result = model.execute()
+
+        # Assert
+        self.assertHasAdditions(source_file, self.result, ['ElectroMechanicalElement EM(k=10 , b=2);'])
+        self.assertHasDeletions(source_file, self.result, ['J=10'])
+
+    def test_model_remove_component_argument_first(self):
+        """Should remove an argument in an existing component."""
+        # Setup
+        source_file = os.path.join(self.data_dir, 'DCMotor.mo')
+        model = Model(source_file)
+
+        # Act
+        model.remove_component_argument('ElectroMechanicalElement', 'EM', 'k')
+        self.result = model.execute()
+
+        # Assert
+        self.assertHasAdditions(source_file, self.result, ['ElectroMechanicalElement EM( J=10, b=2);'])
+        self.assertHasDeletions(source_file, self.result, ['k=10'])
+
+    def test_model_remove_component_argument_last(self):
+        """Should remove an argument in an existing component."""
+        # Setup
+        source_file = os.path.join(self.data_dir, 'DCMotor.mo')
+        model = Model(source_file)
+
+        # Act
+        model.remove_component_argument('ElectroMechanicalElement', 'EM', 'b')
+        self.result = model.execute()
+
+        # Assert
+        self.assertHasAdditions(source_file, self.result, ['ElectroMechanicalElement EM(k=10, J=10 );'])
+        self.assertHasDeletions(source_file, self.result, ['b=2'])
+
+    def test_model_remove_component_argument_all(self):
+        """Should remove an argument in an existing component."""
+        # Setup
+        source_file = os.path.join(self.data_dir, 'DCMotor.mo')
+        model = Model(source_file)
+
+        # Act
+        model.remove_component_argument('VsourceDC', 'DC', 'f')
+        self.result = model.execute()
+
+        # Assert
+        self.assertHasAdditions(source_file, self.result, [' VsourceDC DC();'])
+        self.assertHasDeletions(source_file, self.result, ['f=10'])
+
     def test_model_remove_first_component_and_add_param(self):
         """Tests that we can successfully resolve overlapping edits of a deletion
         (removing first component) and an insert (adding new param)
@@ -329,6 +436,20 @@ class TestModel(TestCase, DiffAssertions):
         self.assertHasAdditions(source_file, self.result, ['parameter Real myParam=10.0 "a comment"'])
         self.assertHasDeletions(source_file, self.result, ['Resistor R(R=100);'])
 
+    def test_model_remove_constant(self):
+        """Test to remove an entire component that is flagged as a constant type"""
+        # Setup
+        source_file = os.path.join(self.data_dir, 'DCMotor.mo')
+        model = Model(source_file)
+
+        # Act
+        model.remove_component('Integer', 'notUsed')
+        self.result = model.execute()
+
+        # Assert
+        self.assertNoAdditions(source_file, self.result)
+        self.assertHasDeletions(source_file, self.result, ['constant Integer notUsed=5 "unused constant that needs to be deleted";'])
+
     def test_model_update_annotation_when_no_model_annotation_exists(self):
         # Setup
         mo_file = '''
